@@ -4,7 +4,7 @@ from psycopg import AsyncCursor
 from psycopg_pool import AsyncConnectionPool
 from pydantic import BaseModel
 
-from ._operations import exec_query, results
+from ._operations import exec_query
 from .types import Params, Query
 
 T = TypeVar("T", bound=BaseModel)
@@ -25,6 +25,6 @@ class Transaction:
 
     async def __call__(
         self, query: Query, params: Params = (), model: Type[T] = None, **kwargs
-    ) -> list[T | tuple] | int:
+    ) -> list[T | tuple]:
         await exec_query(self._pool, self._cur, query, params, **kwargs)
-        return await results(self._cur)
+        return await self._cur.fetchall() if self._cur.rownumber is not None else []
